Enum any_mpsc::BufRecvError[][src]

pub enum BufRecvError {
    RecvError(RecvError),
    RecvTimeoutError(RecvTimeoutError),
    TryRecvError(TryRecvError),
    WrongType(TypeId),
    EmptyBuffer,
}
Error type for receievers. If an mpsc error occurs, it will be wrapped by an appropriate wrapper variant. If receiver is supplied an incorrect type, a [BufRecvError::WrongType(TypeId)] will be returned and the result will be stored in a buffer. If BufferedReceiver::recv_buf is called with an empty buffer, EmptyBuffer will be returned

Variants

RecvError(RecvError)
RecvTimeoutError(RecvTimeoutError)
TryRecvError(TryRecvError)
WrongType(TypeId)
EmptyBuffer